@@ -12,6 +12,7 @@ from __future__ import absolute_import
 from . import environment
 from . import scheduling
 from . import errors
+from . import testing
 from .project import FlowProject
 from .project import JobOperation
 from .project import label
@@ -25,7 +26,13 @@ from .template import init
 from .util.misc import redirect_log
 from .operations import with_job
 
-__version__ = '0.7.1'
+# Import packaged environments unless disabled in config:
+from .util.config import get_config_value
+if get_config_value('import_packaged_environments', default=True):
+    from . import environments  # noqa:F401
+
+
+__version__ = '0.8.0'
 
 __all__ = [
     'environment',
@@ -42,5 +49,6 @@ __all__ = [
     'init',
     'redirect_log',
     'get_environment',
-    'with_job'
+    'with_job',
+    'testing'
     ]
