@@ -12,12 +12,10 @@ environment, e.g. for the adjustemt of scheduler submission scripts.
 from __future__ import print_function
 from __future__ import division
 import os
-import sys
 import re
 import socket
 import logging
 import importlib
-from math import ceil
 from collections import OrderedDict
 
 from signac.common import config
@@ -31,12 +29,8 @@ from .scheduling.torque import TorqueScheduler
 from .scheduling.simple_scheduler import SimpleScheduler
 from .scheduling.fakescheduler import FakeScheduler
 from .util import config as flow_config
-from .util.template_filters import format_timedelta
-from .errors import SubmitError
 from .errors import NoSchedulerError
 
-from .legacy_templating import JobScript
-
 if six.PY2:
     import imp
 else:
@@ -87,14 +81,6 @@ def setup(py_modules, **attrs):
         **attrs)
 
 
-def deprecated_since_06(func):
-    import deprecation
-
-    return deprecation.deprecated(
-        deprecated_in=0.6, removed_in=0.8,
-        details="This function is part of the legacy templating system.")(func)
-
-
 class ComputeEnvironmentType(type):
     """Meta class for the definition of ComputeEnvironments.
 
@@ -127,16 +113,6 @@ class ComputeEnvironment(with_metaclass(ComputeEnvironmentType)):
     submit_flags = None
     template = 'base_script.sh'
 
-    @classmethod
-    @deprecated_since_06
-    def script(cls, **kwargs):
-        """Return a JobScript instance.
-
-        Derived ComputeEnvironment classes may require additional
-        arguments for the creation of a job submission script.
-        """
-        return JobScript(cls)
-
     @classmethod
     def is_present(cls):
         """Determine whether this specific compute environment is present.
@@ -181,17 +157,9 @@ class ComputeEnvironment(with_metaclass(ComputeEnvironmentType)):
             flags.extend(env_flags)
 
         # Hand off the actual submission to the scheduler
-        if isinstance(script, JobScript):  # api version < 6
-            script = str(script)
-
         if cls.get_scheduler().submit(script, flags=flags, *args, **kwargs):
             return JobStatus.submitted
 
-    @staticmethod
-    def bg(cmd):
-        "Wrap a command (cmd) to be executed in the background."
-        return cmd + ' &'
-
     @classmethod
     def add_args(cls, parser):
         """Add arguments related to this compute environment to an argument parser.
@@ -247,10 +215,9 @@ class UnknownEnvironment(StandardEnvironment):
     "Deprecated 'standard' environment, replaced by 'StandardEnvironment.'"
 
     def __init__(self, *args, **kwargs):
-        super(
-            "The 'UnknownEnvironment' class has been replaced by the "
-            "'StandardEnvironment' class.", DeprecationWarning)
-        super(UnknownEnvironment, self).__init__(*args, **kwargs)
+        raise RuntimeError(
+            "The 'flow.environment.UnknownEnvironment' class has been replaced by the "
+            "'flow.environment.StandardEnvironment' class.")
 
 
 class TestEnvironment(ComputeEnvironment):
@@ -263,19 +230,6 @@ class TestEnvironment(ComputeEnvironment):
     """
     scheduler_type = FakeScheduler
 
-    @classmethod
-    @deprecated_since_06
-    def mpi_cmd(cls, cmd, np):
-        return 'mpirun -np {np} {cmd}'.format(np=np, cmd=cmd)
-
-    @classmethod
-    @deprecated_since_06
-    def script(cls, **kwargs):
-        js = super(TestEnvironment, cls).script(**kwargs)
-        for key in sorted(kwargs):
-            js.writeline('#TEST {}={}'.format(key, kwargs[key]))
-        return js
-
 
 class SimpleSchedulerEnvironment(ComputeEnvironment):
     "An environment for the simple-scheduler scheduler."
@@ -307,46 +261,10 @@ class NodesEnvironment(ComputeEnvironment):
     Each compute node is assumed to have a specific number of compute units, e.g., CPUs.
     """
 
-    @classmethod
-    @deprecated_since_06
-    def calc_num_nodes(cls, np_total, ppn, force=False, **kwargs):
-        if ppn is None:
-            try:
-                ppn = getattr(cls, 'cores_per_node')
-            except AttributeError:
-                from .legacy_templating import NUM_NODES_WARNING
-                raise SubmitError(NUM_NODES_WARNING)
-
-        # Calculate the total number of required nodes
-        nn = int(ceil(np_total / ppn))
-
-        if not force:  # Perform basic check concerning the node utilization.
-            usage = np_total / nn / ppn
-            if usage < 0.9:
-                from .legacy_templating import UTILIZATION_WARNING
-                print(UTILIZATION_WARNING.format(ppn=ppn, usage=usage), file=sys.stderr)
-                raise SubmitError("Bad node utilization!")
-        return nn
-
-    @classmethod
-    @deprecated_since_06
-    def add_args(cls, parser):
-        super(NodesEnvironment, cls).add_args(parser)
-        parser.add_argument(
-            '--nn',
-            type=int,
-            help="Specify the total number of nodes. This value is computed automatically "
-                 "from the 'np' directive otherwise.")
-
 
 class DefaultTorqueEnvironment(NodesEnvironment, TorqueEnvironment):
     "A default environment for environments with TORQUE scheduler."
 
-    @classmethod
-    @deprecated_since_06
-    def mpi_cmd(cls, cmd, np):
-        return 'mpirun -np {np} {cmd}'.format(np=np, cmd=cmd)
-
     @classmethod
     def add_args(cls, parser):
         super(DefaultTorqueEnvironment, cls).add_args(parser)
@@ -368,52 +286,10 @@ class DefaultTorqueEnvironment(NodesEnvironment, TorqueEnvironment):
             action='store_true',
             help="Do not copy current environment variables into compute node environment.")
 
-    @classmethod
-    @deprecated_since_06
-    def gen_tasks(cls, js, np_total):
-        """Helper function to generate the number of tasks (for overriding)"""
-        js.writeline('#PBS -l nodes={}'.format(np_total))
-        return js
-
-    @classmethod
-    @deprecated_since_06
-    def script(cls, _id, np_total, walltime=None, no_copy_env=False, **kwargs):
-        js = super(DefaultTorqueEnvironment, cls).script()
-        js.writeline('#PBS -N {}'.format(_id))
-        js = cls.gen_tasks(js)
-        if walltime is not None:
-            js.writeline('#PBS -l walltime={}'.format(format_timedelta(walltime)))
-        if not no_copy_env:
-            js.writeline('#PBS -V')
-        return js
-
 
 class DefaultSlurmEnvironment(NodesEnvironment, SlurmEnvironment):
     "A default environment for environments with SLURM scheduler."
 
-    @classmethod
-    @deprecated_since_06
-    def mpi_cmd(cls, cmd, np):
-        return 'mpirun -np {np} {cmd}'.format(np=np, cmd=cmd)
-
-    @classmethod
-    @deprecated_since_06
-    def gen_tasks(cls, js, np_total):
-        """Helper function to generate the number of tasks (for overriding)"""
-        js.writeline('#SBATCH --ntasks={}'.format(np_total))
-        return js
-
-    @classmethod
-    @deprecated_since_06
-    def script(cls, _id, np_total, walltime=None, **kwargs):
-        js = super(DefaultSlurmEnvironment, cls).script()
-        js.writeline('#!/bin/bash')
-        js.writeline('#SBATCH --job-name="{}"'.format(_id))
-        js = cls.gen_tasks(js, np_total)
-        if walltime is not None:
-            js.writeline('#SBATCH -t {}'.format(format_timedelta(walltime)))
-        return js
-
     @classmethod
     def add_args(cls, parser):
         super(DefaultSlurmEnvironment, cls).add_args(parser)
@@ -437,25 +313,6 @@ class DefaultLSFEnvironment(NodesEnvironment, LSFEnvironment):
     "A default environment for environments with LSF scheduler."
 
     @classmethod
-    @deprecated_since_06
-    def mpi_cmd(cls, cmd, np):
-        raise NotImplementedError("LSF environments are not supported by the "
-                                  "legacy templating system.")
-
-    @classmethod
-    @deprecated_since_06
-    def gen_tasks(cls, js, np_total):
-        raise NotImplementedError("LSF environments are not supported by the "
-                                  "legacy templating system.")
-
-    @classmethod
-    @deprecated_since_06
-    def script(cls, _id, np_total, walltime=None, **kwargs):
-        raise NotImplementedError("LSF environments are not supported by the "
-                                  "legacy templating system.")
-
-    @classmethod
-    @deprecated_since_06
     def add_args(cls, parser):
         super(DefaultLSFEnvironment, cls).add_args(parser)
         parser.add_argument(
